/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.common.constant;

/**
 * Constants of cluster switching
 */
public class ClusterSwitch {

    /**
     * Cluster tag for backup.
     */
    public static final String BACKUP_CLUSTER_TAG = "backup_cluster_tag";

    /**
     * MQ resource for backup, represents the namespace of Pulsar, the topic of TubeMQ, etc.
     */
    public static final String BACKUP_MQ_RESOURCE = "backup_mq_resource";

    /**
     * Cluster swtich start time
     */
    public static final String CLUSTER_SWITCH_TIME = "cluster_switch_time";

    public static final int FINISH_SWITCH_INTERVAL_MIN = 10;
}
